@@ -1,5 +1,20 @@
+".onLoad" <-
+function (lib, pkg)
+{
+	# Create our SciViews task callback manager
+	assignTemp(".svTaskCallbackManager", svTaskCallbackManager())
+}
+
+".onUnload" <-
+function (libpath)
+{
+	removeTaskCallback("SV-taskCallbackManager")
+	rmTemp(".svTaskCallbackManager")
+}
+
 ".Last.lib" <-
-function (libpath) {   
+function (libpath)
+{
     # Make sure that all clients are disconnected
     # and all servers are closed
     Servers <- getSocketServers()
